Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(816)

Unified Diff: components/wallpaper/wallpaper_manager_base.cc

Issue 1747843002: Rename raw_image() to image_bytes() in UserImage (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: address comments Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/wallpaper/wallpaper_manager_base.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/wallpaper/wallpaper_manager_base.cc
diff --git a/components/wallpaper/wallpaper_manager_base.cc b/components/wallpaper/wallpaper_manager_base.cc
index 6cd4d62bc481ca7493914b2bd1b521b639842b14..23c74ce022897b356f6bb80ab9c38bc6904a6e15 100644
--- a/components/wallpaper/wallpaper_manager_base.cc
+++ b/components/wallpaper/wallpaper_manager_base.cc
@@ -914,10 +914,10 @@ void WallpaperManagerBase::OnCustomizedDefaultWallpaperDecoded(
scoped_ptr<gfx::ImageSkia> small_wallpaper_image(new gfx::ImageSkia);
scoped_ptr<gfx::ImageSkia> large_wallpaper_image(new gfx::ImageSkia);
// TODO(bshe): This may break if RawImage becomes RefCountedMemory.
base::Closure resize_closure = base::Bind(
&WallpaperManagerBase::ResizeCustomizedDefaultWallpaper,
- base::Passed(&deep_copy), wallpaper.raw_image(),
+ base::Passed(&deep_copy), wallpaper.image_bytes(),
base::Unretained(rescaled_files.get()), base::Unretained(success.get()),
base::Unretained(small_wallpaper_image.get()),
base::Unretained(large_wallpaper_image.get()));
@@ -936,7 +936,7 @@ void WallpaperManagerBase::OnCustomizedDefaultWallpaperDecoded(
void WallpaperManagerBase::ResizeCustomizedDefaultWallpaper(
scoped_ptr<gfx::ImageSkia> image,
- const user_manager::UserImage::RawImage& raw_image,
+ const user_manager::UserImage::Bytes& image_bytes,
const CustomizedWallpaperRescaledFiles* rescaled_files,
bool* success,
gfx::ImageSkia* small_wallpaper_image,
@@ -914,10 +914,10 @@ void WallpaperManagerBase::OnCustomizedDefaultWallpaperDecoded(
scoped_ptr<gfx::ImageSkia> small_wallpaper_image(new gfx::ImageSkia);
scoped_ptr<gfx::ImageSkia> large_wallpaper_image(new gfx::ImageSkia);
- // TODO(bshe): This may break if RawImage becomes RefCountedMemory.
+ // TODO(bshe): This may break if Bytes becomes RefCountedMemory.
base::Closure resize_closure = base::Bind(
&WallpaperManagerBase::ResizeCustomizedDefaultWallpaper,
« no previous file with comments | « components/wallpaper/wallpaper_manager_base.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698